@@ -1,25 +1,9 @@
 /*
-  Copyright (c) 1998 Barry D Benowitz <b.benowitz@telesciences.com>
-  Copyright (c) 2001 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (c) 2009 Allen Winter <winter@kde.org>
+  SPDX-FileCopyrightText: 1998 Barry D Benowitz <b.benowitz@telesciences.com>
+  SPDX-FileCopyrightText: 2001 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2009 Allen Winter <winter@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include <config-enterprise.h>
@@ -34,7 +18,6 @@
 
 #include <KCalendarCore/Attendee>
 #include <KCalendarCore/Incidence>
-#include <KCalendarCore/IncidenceBase>
 
 #include <KCalUtils/IncidenceFormatter>
 
@@ -126,7 +109,7 @@ bool MailClient::mailAttendees(const KCalendarCore::IncidenceBase::Ptr &incidenc
 
     QString subject;
     if (incidence->type() != KCalendarCore::Incidence::TypeFreeBusy) {
-        KCalendarCore::Incidence::Ptr inc = incidence.staticCast<KCalendarCore::Incidence>();
+        const KCalendarCore::Incidence::Ptr inc = incidence.staticCast<KCalendarCore::Incidence>();
         subject = inc->summary();
     } else {
         subject = i18n("Free Busy Object");
@@ -145,7 +128,7 @@ bool MailClient::mailOrganizer(const KCalendarCore::IncidenceBase::Ptr &incidenc
     QString subject = sub;
 
     if (incidence->type() != KCalendarCore::Incidence::TypeFreeBusy) {
-        KCalendarCore::Incidence::Ptr inc = incidence.staticCast<KCalendarCore::Incidence>();
+        const KCalendarCore::Incidence::Ptr inc = incidence.staticCast<KCalendarCore::Incidence>();
         if (subject.isEmpty()) {
             subject = inc->summary();
         }
@@ -275,7 +258,7 @@ bool MailClient::send(const KIdentityManagement::Identity &identity, const QStri
         message->contentType()->setParameter(QStringLiteral("method"), QStringLiteral("request"));
 
         if (!attachment.isEmpty()) {
-            KMime::Headers::ContentDisposition *disposition
+            auto *disposition
                 = new KMime::Headers::ContentDisposition;
             disposition->setDisposition(KMime::Headers::CDinline);
             message->setHeader(disposition);
@@ -293,8 +276,8 @@ bool MailClient::send(const KIdentityManagement::Identity &identity, const QStri
         ct->setCategory(KMime::Headers::CCcontainer);
 
         // Set the first multipart, the body message.
-        KMime::Content *bodyMessage = new KMime::Content;
-        KMime::Headers::ContentDisposition *bodyDisposition
+        auto *bodyMessage = new KMime::Content;
+        auto *bodyDisposition
             = new KMime::Headers::ContentDisposition;
         bodyDisposition->setDisposition(KMime::Headers::CDinline);
         bodyMessage->contentType()->setMimeType("text/plain");
@@ -306,8 +289,8 @@ bool MailClient::send(const KIdentityManagement::Identity &identity, const QStri
 
         // Set the second multipart, the attachment.
         if (!attachment.isEmpty()) {
-            KMime::Content *attachMessage = new KMime::Content;
-            KMime::Headers::ContentDisposition *attachDisposition
+            auto *attachMessage = new KMime::Content;
+            auto *attachDisposition
                 = new KMime::Headers::ContentDisposition;
             attachDisposition->setDisposition(KMime::Headers::CDattachment);
             attachMessage->contentType()->setMimeType("text/calendar");
@@ -326,7 +309,7 @@ bool MailClient::send(const KIdentityManagement::Identity &identity, const QStri
     message->assemble();
 
     // Put the newly created item in the MessageQueueJob.
-    MailTransport::MessageQueueJob *qjob = new MailTransport::MessageQueueJob(this);
+    auto *qjob = new MailTransport::MessageQueueJob(this);
     qjob->transportAttribute().setTransportId(transportId);
 
     if (identity.disabledFcc()) {
