@@ -1,21 +1,8 @@
 /*
-  Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
-    Author: Tobias Koenig <tokoe@kdab.com>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+  SPDX-FileContributor: Tobias Koenig <tokoe@kdab.com>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "collectiongeneralpage.h"
@@ -46,11 +33,6 @@ using namespace CalendarSupport;
 
 CollectionGeneralPage::CollectionGeneralPage(QWidget *parent)
     : CollectionPropertiesPage(parent)
-    , mBlockAlarmsCheckBox(nullptr)
-    , mNameEdit(nullptr)
-    , mIconCheckBox(nullptr)
-    , mIconButton(nullptr)
-    , mIncidencesForComboBox(nullptr)
 {
     setObjectName(QStringLiteral("CalendarSupport::CollectionGeneralPage"));
     setPageTitle(i18nc("@title:tab General settings for a folder.", "General"));
@@ -58,9 +40,9 @@ CollectionGeneralPage::CollectionGeneralPage(QWidget *parent)
 
 void CollectionGeneralPage::init(const Akonadi::Collection &collection)
 {
-    QVBoxLayout *topLayout = new QVBoxLayout(this);
+    auto *topLayout = new QVBoxLayout(this);
 
-    QHBoxLayout *hbox = new QHBoxLayout();
+    auto *hbox = new QHBoxLayout();
     topLayout->addItem(hbox);
 
     QLabel *label = new QLabel(i18nc("@label:textbox Name of the folder.", "&Name:"), this);
@@ -104,7 +86,7 @@ void CollectionGeneralPage::init(const Akonadi::Collection &collection)
 
     if ((collection.parentCollection() != Akonadi::Collection::root())
         && PimCommon::Util::isImapResource(collection.resource())) {
-        const PimCommon::CollectionAnnotationsAttribute *annotationAttribute
+        const auto *annotationAttribute
             = collection.attribute<PimCommon::CollectionAnnotationsAttribute>();
 
         const QMap<QByteArray, QByteArray> annotations
@@ -178,7 +160,7 @@ void CollectionGeneralPage::save(Collection &collection)
         collection.setName(mNameEdit->text());
     }
 
-    BlockAlarmsAttribute *attr
+    auto *attr
         = collection.attribute<BlockAlarmsAttribute>(Collection::AddIfMissing);
     attr->blockEverything(mBlockAlarmsCheckBox->isChecked());
 
@@ -188,7 +170,7 @@ void CollectionGeneralPage::save(Collection &collection)
     } else if (collection.hasAttribute<EntityDisplayAttribute>()) {
         collection.attribute<EntityDisplayAttribute>()->setIconName(QString());
     }
-    PimCommon::CollectionAnnotationsAttribute *annotationsAttribute
+    auto *annotationsAttribute
         = collection.attribute<PimCommon::CollectionAnnotationsAttribute>(Collection::AddIfMissing);
 
     QMap<QByteArray, QByteArray> annotations = annotationsAttribute->annotations();
