@@ -1,25 +1,9 @@
 /*
   This file is part of KOrganizer.
-  Copyright (c) 2001 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2001 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "koagendaview.h"
@@ -61,8 +45,8 @@ KOAgendaView::KOAgendaView(QWidget *parent, bool isSideBySide)
     : KOEventView(parent)
     , d(new Private(isSideBySide, this))
 {
-    QHBoxLayout *layout = new QHBoxLayout(this);
-    layout->setContentsMargins(0, 0, 0, 0);
+    auto *layout = new QHBoxLayout(this);
+    layout->setContentsMargins({});
     layout->addWidget(d->mAgendaView);
 
     connect(d->mAgendaView, &EventViews::AgendaView::zoomViewHorizontally,
@@ -165,12 +149,12 @@ void KOAgendaView::zoomOutVertically()
     d->mAgendaView->zoomOutVertically();
 }
 
-void KOAgendaView::zoomInHorizontally(const QDate &date)
+void KOAgendaView::zoomInHorizontally(QDate date)
 {
     d->mAgendaView->zoomInHorizontally(date);
 }
 
-void KOAgendaView::zoomOutHorizontally(const QDate &date)
+void KOAgendaView::zoomOutHorizontally(QDate date)
 {
     d->mAgendaView->zoomOutHorizontally(date);
 }
